]> ruderich.org/simon Gitweb - config/dotfiles.git/blobdiff - lib.sh
lib.sh: Use `type` instead of `which`.
[config/dotfiles.git] / lib.sh
diff --git a/lib.sh b/lib.sh
index 95c2fdf5c83efdc37212468d00e8f4c837ca7ac8..d150778e36bccc09036ba1c5a5a33257005f37f5 100644 (file)
--- a/lib.sh
+++ b/lib.sh
 unset LS_COLORS
 
 
# Check if the given program is installed. Returns 0 if it exists, 1
# otherwise; so it can be used in if.
 installed() {
-    [ x`which $1 2>&1 | cut -c 1` = x/ ] || return 1
+    type "$1" >/dev/null 2>&1
 }
 
 # Print the current OS. The following OS are supported at the moment:
@@
 
 
-# Check if the given program is installed. Returns 0 if it exists, 1
-# otherwise; so it can be used in if.
+# Check if the given program is installed. `type` is portable, `which` is not.
 installed() {